package de.hhhammer.chatrelay;

import net.dv8tion.jda.api.JDA;
import net.dv8tion.jda.api.JDABuilder;
import net.dv8tion.jda.api.entities.channel.concrete.TextChannel;
import net.dv8tion.jda.api.interactions.commands.build.Commands;
import net.dv8tion.jda.api.requests.GatewayIntent;
import org.bukkit.plugin.java.JavaPlugin;

import java.util.Objects;
import java.util.logging.Level;
import java.util.logging.Logger;

public final class ChatRelay extends JavaPlugin {
    private final String discordToken = "";
    private final String guildId = "";
    private final String channelId = "";
    private final Logger logger = this.getLogger();
    private JDA jda;
    private DiscordMessageChannel discordMessageChannel;

    @Override
    public void onEnable() {
        var server = this.getServer();
        var messageListener = new DiscordEventListener(guildId, channelId, server);
        this.jda = JDABuilder.createDefault(discordToken)
                .enableIntents(GatewayIntent.MESSAGE_CONTENT)
                .addEventListeners(messageListener)
                .build();
        try {
            jda.awaitReady();
        } catch (InterruptedException e) {
            throw new RuntimeException(e);
        }
        jda.updateCommands().addCommands(Commands.slash("list", "List of all online players.")).queue();
        discordMessageChannel = new DiscordMessageChannel(obtainTargetChannel(jda));
        server.getPluginManager().registerEvents(new MinecraftEventListener(discordMessageChannel), this);
        logger.log(Level.INFO, "Bot is now online.");
        discordMessageChannel.sendServerEvent("Server is now online.");
    }

    @Override
    public void onDisable() {
        discordMessageChannel.sendServerEvent("Server is shutting down.");
        jda.shutdown();
        try {
            jda.awaitShutdown();
        } catch (InterruptedException e) {
            throw new RuntimeException(e);
        }

        logger.log(Level.INFO, "Bot is now offline.");
    }

    private TextChannel obtainTargetChannel(JDA jda) {
        var guild = jda.getGuildById(this.guildId);
        Objects.requireNonNull(guild);
        var channel = guild.getTextChannelById(channelId);
        Objects.requireNonNull(channel);
        return channel;
    }

}
