package de.hhhammer.chatrelay;

import net.dv8tion.jda.api.entities.channel.ChannelType;
import net.dv8tion.jda.api.events.interaction.command.SlashCommandInteractionEvent;
import net.dv8tion.jda.api.events.message.MessageReceivedEvent;
import net.dv8tion.jda.api.hooks.ListenerAdapter;
import net.kyori.adventure.text.Component;
import net.kyori.adventure.text.format.NamedTextColor;
import org.bukkit.Server;

import java.util.stream.Collectors;

public class DiscordEventListener extends ListenerAdapter {
    private final String guildId;
    private final String channelId;
    private final Server server;

    public DiscordEventListener(String guildId, String channelId, Server server) {
        this.guildId = guildId;
        this.channelId = channelId;
        this.server = server;
    }

    @Override
    public void onMessageReceived(MessageReceivedEvent event) {
        if (!event.isFromType(ChannelType.TEXT) && !event.getGuild().getId().equals(guildId) && !event.getChannel().getId().equals(channelId)) {
            return;
        }
        // Ignore if message was send by the bot
        if (event.getJDA()
                .getSelfUser()
                .getId()
                .equals(event.getAuthor()
                        .getId())) {
            return;
        }
        var message = Component.text(event.getAuthor().getEffectiveName() + ": ", NamedTextColor.GREEN)
                .append(Component.text(event.getMessage().getContentDisplay()));
        this.server.broadcast(message);
    }

    @Override
    public void onSlashCommandInteraction(SlashCommandInteractionEvent event) {
        switch (event.getName()) {
            case "list":
                var maxPlayer = server.getMaxPlayers();
                var players = server.getOnlinePlayers();
                var listOfPlayers = players.stream()
                        .map(player -> "- " + player.getName() + "\n")
                        .collect(Collectors.joining());
                event.reply("_Server_: Following players are online (" + players.size() + "/" + maxPlayer + "):\n" + listOfPlayers).queue();
                break;
        }
    }
}
