package de.hhhammer.chatrelay;

import io.papermc.paper.event.player.AsyncChatEvent;
import net.kyori.adventure.text.TextComponent;
import net.kyori.adventure.text.serializer.plain.PlainComponentSerializer;
import net.kyori.adventure.text.serializer.plain.PlainTextComponentSerializer;
import org.bukkit.event.EventHandler;
import org.bukkit.event.Listener;
import org.bukkit.event.entity.PlayerDeathEvent;
import org.bukkit.event.player.PlayerJoinEvent;
import org.bukkit.event.player.PlayerQuitEvent;

public class MinecraftEventListener implements Listener {
    private final DiscordMessageChannel discordMessageChannel;

    public MinecraftEventListener(DiscordMessageChannel discordMessageChannel) {
        this.discordMessageChannel = discordMessageChannel;
    }

    @EventHandler
    public void onPlayerMessage(AsyncChatEvent event) {
        var message = event.message();
        if (message instanceof TextComponent textMessage) {
            discordMessageChannel.sendPlayerEvent(event.getPlayer().getName(), textMessage.content());
        }
    }

    @EventHandler
    public void onPlayerJoin(PlayerJoinEvent event) {
        discordMessageChannel.sendServerEvent(event.getPlayer().getName() + " joined the server.");
    }


    @EventHandler
    public void onPlayerDisconnect(PlayerQuitEvent event) {
        discordMessageChannel.sendServerEvent(event.getPlayer().getName() + " left the server.");
    }

    @EventHandler
    public void onPlayerDeath(PlayerDeathEvent event) {
        var deathMsgComponent = event.deathMessage();
        if (deathMsgComponent == null) {
            return;
        }
        var deathMsg = PlainTextComponentSerializer.plainText().serialize(deathMsgComponent);
        discordMessageChannel.sendServerEvent(deathMsg);
    }
}
